@@ -89,8 +89,10 @@ bool isValid(const cDateTime &datetime)
 void validate(const Event &event)
 {
     ASSERTVALID(event.created());
-    ASSERT(event.created().isUTC());
-    ASSERT(!event.created().isDateOnly());
+    if (event.created().isValid()) {
+        ASSERT(event.created().isUTC());
+        ASSERT(!event.created().isDateOnly());
+    }
     ASSERTEXISTING(event.start());
     ASSERTVALID(event.start());
     ASSERTVALID(event.end());
@@ -102,8 +104,10 @@ void validate(const Event &event)
 void validate(const Todo& todo)
 {
     ASSERTVALID(todo.created());
-    ASSERT(todo.created().isUTC());
-    ASSERT(!todo.created().isDateOnly());
+    if (todo.created().isValid()) {
+        ASSERT(todo.created().isUTC());
+        ASSERT(!todo.created().isDateOnly());
+    }
     ASSERTVALID(todo.start());
     ASSERTVALID(todo.due());
     if (todo.start().isValid() && todo.due().isValid()) {
@@ -114,8 +118,10 @@ void validate(const Todo& todo)
 void validate(const Journal& journal)
 {
     ASSERTVALID(journal.created());
-    ASSERT(journal.created().isUTC());
-    ASSERT(!journal.created().isDateOnly());
+    if (journal.created().isValid()) {
+        ASSERT(journal.created().isUTC());
+        ASSERT(!journal.created().isDateOnly());
+    }
     ASSERTVALID(journal.start());
 }
 
