@@ -21,7 +21,7 @@
 std::string uriEncode(const std::string &s)
 {
     CURL *easyhandle = curl_easy_init();
-    const char *result = curl_easy_escape(easyhandle, s.c_str(), s.length());
+    char *result = curl_easy_escape(easyhandle, s.c_str(), static_cast<int>(s.length()));
     curl_easy_cleanup(easyhandle);
     if (!result) {
         return std::string();
@@ -35,7 +35,7 @@ std::string uriDecode(const std::string &s)
 {
     CURL *easyhandle = curl_easy_init();
     int length = 0;
-    const char *result = curl_easy_unescape(easyhandle, s.c_str(), s.length(), &length);
+    char *result = curl_easy_unescape(easyhandle, s.c_str(), static_cast<int>(s.length()), &length);
     curl_easy_cleanup(easyhandle);
     if (!length) {
         return std::string();
