@@ -352,9 +352,12 @@ Kolab::Duration toDuration(const icalendar_2_0::DurationValueType &d)
                 break;
             case 'P':
                 break;
-            default:
-                ERROR("failed to convert duration: " + *it);
+            default: {
+                std::ostringstream s;
+                s << "failed to convert duration: " << *it;
+                ERROR(s.str());
                 return Duration();
+            }
         }
     }
     return Duration(days, hours, minutes, seconds, negative);
@@ -607,7 +610,9 @@ std::string mapPartStat(PartStatus status)
         case PartCompleted:
             return PARTCOMPLETED;
     }
-    ERROR("PartStat not handled: " + status);
+    std::ostringstream s;
+    s << "PartStat not handled: " << status;
+    ERROR(s.str());
     return std::string();
 }
 
@@ -644,7 +649,9 @@ std::string mapRole(Role status)
         case Required:
             return REQUIRED;
     }
-    ERROR("PartStat not handled: " + status);
+    std::ostringstream s;
+    s << "Role not handled: " << status;
+    ERROR(s.str());
     return std::string();
 }
 
@@ -659,7 +666,7 @@ Role mapRole(const std::string &status)
     } else if (status == REQUIRED) {
         return Required;
     }
-    ERROR("Unhandled Role " + status);
+    ERROR("Unhandled status " + status);
     return Required;
 }
 
@@ -693,8 +700,6 @@ Role mapRole(const std::string &status)
                 return RecurrenceRule::Minutely;
             case FreqRecurType::SECONDLY:
                 return RecurrenceRule::Secondly;
-            default:
-                ERROR("invalid unhandled recurrenc type" + freq);
         }
         return RecurrenceRule::FreqNone;
     }
@@ -718,8 +723,8 @@ Role mapRole(const std::string &status)
                 return FreqRecurType::MINUTELY;
             case RecurrenceRule::Secondly:
                 return FreqRecurType::SECONDLY;
-            default:
-                ERROR("invalid unhandled recurrenc type");
+            case RecurrenceRule::FreqNone:
+                return 0;
         }
         return 0;
     }
@@ -750,8 +755,6 @@ Role mapRole(const std::string &status)
             case WeekdayRecurType::SU:
                 r->setWeekStart(Kolab::Sunday);
                 break;
-            default:
-                ERROR("invalid unhandled weekday" + wkst);
         }
     }
 
@@ -1111,11 +1114,11 @@ void getIncidenceProperties(T &prop, const I &inc)
         case Kolab::ClassPrivate:
             prop.class_(typename properties::class_type(PRIVATE));
             break;
-        default:
+        case Kolab::ClassPublic:
             prop.class_(typename properties::class_type(PUBLIC));
             break;
     }
-    
+
     if (!inc.categories().empty()) {
         prop.categories(*fromStringList<typename properties::categories_type>(inc.categories()));
     }
@@ -1136,36 +1139,33 @@ void getIncidenceProperties(T &prop, const I &inc)
         prop.comment(typename properties::comment_type(inc.comment()));
     }
 
-    if (inc.status() != StatusUndefined) {
-        switch (inc.status()) {
-            case StatusNeedsAction:
-                prop.status(typename properties::status_type(NEEDSACTION));
-                break;
-            case StatusCompleted:
-                prop.status(typename properties::status_type(COMPLETED));
-                break;
-            case StatusInProcess:
-                prop.status(typename properties::status_type(INPROCESS));
-                break;
-            case StatusCancelled:
-                prop.status(typename properties::status_type(CANCELLED));
-                break;
-            case StatusTentative:
-                prop.status(typename properties::status_type(TENTATIVE));
-                break;
-            case StatusConfirmed:
-                prop.status(typename properties::status_type(CONFIRMED));
-                break;
-            case StatusDraft:
-                prop.status(typename properties::status_type(DRAFT));
-                break;
-            case StatusFinal:
-                prop.status(typename properties::status_type(FINAL));
-                break;
-            default:
-                ERROR("unhandled status " + inc.status());
-        }
-
+    switch (inc.status()) {
+        case StatusNeedsAction:
+            prop.status(typename properties::status_type(NEEDSACTION));
+            break;
+        case StatusCompleted:
+            prop.status(typename properties::status_type(COMPLETED));
+            break;
+        case StatusInProcess:
+            prop.status(typename properties::status_type(INPROCESS));
+            break;
+        case StatusCancelled:
+            prop.status(typename properties::status_type(CANCELLED));
+            break;
+        case StatusTentative:
+            prop.status(typename properties::status_type(TENTATIVE));
+            break;
+        case StatusConfirmed:
+            prop.status(typename properties::status_type(CONFIRMED));
+            break;
+        case StatusDraft:
+            prop.status(typename properties::status_type(DRAFT));
+            break;
+        case StatusFinal:
+            prop.status(typename properties::status_type(FINAL));
+            break;
+        case StatusUndefined:
+            break;
     }
 
     if (!inc.attendees().empty()) {        
@@ -1222,9 +1222,7 @@ void getIncidenceProperties(T &prop, const I &inc)
                     case CutypeUnknown:
                         type = UNKNOWN;
                         break;
-                    default:
-                        WARNING("unknown cutype");
-                        type = INDIVIDUAL;
+                    case CutypeIndividual: // silence compiler warning
                         break;
                 }
                 p.baseParameter().push_back(icalendar_2_0::CutypeParamType(type));
@@ -1357,9 +1355,8 @@ void setAlarms(typename KolabType::components_type& components, const IncidenceT
                     p->attach(fromAttachment(alarm.audioFile()));
                 }
                 break;
-            default:
-                ERROR("invalid alarm");
-                continue;
+            case Kolab::Alarm::InvalidAlarm:
+                break;
         }
         if (alarm.duration().isValid()) {
             p->duration(PropType::duration_type(fromDuration(alarm.duration())));
@@ -1740,7 +1737,6 @@ template < > struct IncidenceTrait <Kolab::Freebusy>
                         fbtype = BUSY_OUTOFOFFICE;
                         break;
                     case FreebusyPeriod::Invalid:
-                    default:
                         WARNING("Invalid fb type");
                         continue;
                 }
@@ -1912,7 +1908,7 @@ std::string serializeIncidence(const typename T::IncidenceType &incidence, const
         std::ostringstream ostringstream;
         icalendar_2_0::icalendar(ostringstream, icalendar, map);
         return ostringstream.str();
-    } catch  (const xml_schema::exception& e) {
+    } catch  (const xml_schema::exception&) {
         CRITICAL("failed to write Incidence");
     } catch (...) {
         CRITICAL("Unhandled exception");
