@@ -9,11 +9,11 @@
 #include <boost/thread.hpp>
 #include <curl/curlver.h>
 
-Q_DECLARE_METATYPE(Kolab::Duration);
-Q_DECLARE_METATYPE(Kolab::DayPos);
-Q_DECLARE_METATYPE(Kolab::cDateTime);
-Q_DECLARE_METATYPE(Kolab::ErrorSeverity);
-Q_DECLARE_METATYPE(std::string);
+Q_DECLARE_METATYPE(Kolab::Duration)
+Q_DECLARE_METATYPE(Kolab::DayPos)
+Q_DECLARE_METATYPE(Kolab::cDateTime)
+Q_DECLARE_METATYPE(Kolab::ErrorSeverity)
+Q_DECLARE_METATYPE(std::string)
 
 using namespace Kolab::XCAL;
 
